@@ -251,7 +251,74 @@ class DiscordBot(commands.Bot):
             return discord.Status.online
         else:
             raise ValueError(f"Invalid status string \"{status}\"")
-            
+        
+    async def _send_emoji_prepended_embed(self, ctx: commands.Context, emoji: str, content: str):
+        """Sends an embed with an emoji and space both prepended to the left of the desired content to send
+
+        This is mostly here to avoid dupicate code
+
+        Parameters
+        ----------
+        ctx : discord.abc.Messageable
+            The channel, context, or user to send the embed to
+        emoji : str
+            The desired emoji to prepend to `content`
+        content : str
+            The content to send. `emoji` and a space automatically prepended
+            and truncated into the embed description
+        """
+
+        embed = get_base_embed(description=f"{emoji} {content}", color=discord.Color.green(), timestamp=discord.Embed.Empty)
+        await ctx.send(embed=embed)
+
+    async def send_success_embed(self, ctx: discord.abc.Messageable, content: str):
+        """Sends an embed with a white checkmark emoji and a space prepended to the rest of the content
+
+        The description is automatically truncated to the maximum allowed embed description length
+
+        Parameters
+        ----------
+        ctx : discord.abc.Messageable
+            The channel, context, or user to send the embed to
+        content : str
+            The content to send. There is a ":white_check_mark:" emoji and a space automatically prepended
+            and truncated into the embed description
+        """
+
+        await self._send_emoji_prepended_embed(ctx, ":white_check_mark:", content)
+
+    async def send_fail_embed(self, ctx: discord.abc.Messageable, content: str):
+        """Sends an embed with a x emoji and a space prepended to the rest of the content
+
+        The description is automatically truncated to the maximum allowed embed description length
+
+        Parameters
+        ----------
+        ctx : discord.abc.Messageable
+            The channel, context, or user to send the embed to
+        content : str
+            The content to send. There is a ":x:" emoji and a space automatically prepended
+            and truncated into the embed description
+        """
+
+        await self._send_emoji_prepended_embed(ctx, ":x:", content)
+    
+    async def send_warn_embed(self, ctx: discord.abc.Messageable, content: str):
+        """Sends an embed with a warning emoji and a space prepended to the rest of the content
+
+        The description is automatically truncated to the maximum allowed embed description length
+
+        Parameters
+        ----------
+        ctx : discord.abc.Messageable
+            The channel, context, or user to send the embed to
+        content : str
+            The content to send. There is a ":warning:" emoji and a space automatically prepended
+            and truncated into the embed description
+        """
+
+        await self._send_emoji_prepended_embed(ctx, ":warning:", content)
+
     @staticmethod
     async def _retrieve_entity(snowflake: int, func: Callable[[int], Any], coro: Awaitable[int]):
         """Lazily retrieves a discord object from a given discord id
