@@ -1,3 +1,4 @@
+import copy
 import datetime
 import discord
 from contextlib import redirect_stdout
@@ -5,15 +6,68 @@ from discord.ext import commands
 from io import StringIO
 from textwrap import indent
 from traceback import format_exc
+from ..utils import *
 
 class CogConverter(commands.Converter):
+    """Converter to convert strings into cogs"""
+
     async def convert(self, ctx: commands.Context, argument: str) -> commands.Cog:
+        """Attempts to convert a string into a named cog
+
+        Parameters
+        ----------
+        ctx : commands.Context
+            The invokation context, usually fed from an executing command
+        argument : str
+            The argument to attempt to convert into a named cog
+        
+        Raises
+        ------
+        `commands.BadArgument` if the cog was not found
+        """
+
         cog = ctx.bot.get_cog(argument)
         if cog is None:
-            raise commands.ExtensionNotFound(argument)
+            raise commands.BadArgument(f"No cog named \"{argument}\" found")
         return cog
 
 
+class AnyChannel(commands.Converter):
+    """Converter for converting channel mentions, Discord IDs, etc into a valid Discord channel
+
+    Taken from the `GlobalChannel` converter from https://github.com/Rapptz/RoboDanny/blob/644e588851bccca24f220b74f0ef091c48299757/cogs/admin.py
+    """
+
+    async def convert(self, ctx: commands.Context, argument: str):
+        """Attempts to convert any Discord ID to a valid Discord Text Channel, Voice Channel, etc that the bot can fetch/see
+
+        Parameters
+        ----------
+        ctx : commands.Context
+            The invokation context, usually fed from an executing command
+        argument : str
+            The argument to attempt to convert into a Discord channel
+        
+        Raises
+        ------
+        `commands.BadArgument` if the channel was not found
+        """
+
+        try:
+            return await commands.TextChannelConverter().convert(argument)
+        except commands.BadArgument:
+            try:
+                channel_id = int(argument, base=10)
+            except ValueError:
+                # couldn't convert argument to channel id
+                raise commands.BadArgument(f"Couldn't convert {argument!r} into a global channel to fetch")
+            else:
+                channel = ctx.bot.get_channel(channel_id)
+                if channel is not None:
+                    raise commands.BadArgument(f"No channel with ID {argument!r} found")
+
+
+
 class Meta(commands.Cog):
     """
     Default commands and listeners and stuffs
@@ -125,6 +179,25 @@ class Meta(commands.Cog):
                     )
                 await ctx.send(text)
     
+    @commands.is_owner()
+    @commands.command(name="sudo")
+    async def sudo_command(self, ctx: commands.Context, channel: Optional[AnyChannel], user: Union[discord.Member, discord.User], *, command: str):
+        """
+        Executes a command as another user, in another channel
+
+        The `channel` parameter is optional and defaults to the current channel if not supplied, and does not have to be a channel from the current guild
+        """
+
+        message = copy.copy(ctx.message)
+        channel = channel or ctx.channel
+        
+        # reconstruct message so that it points in the other channel
+        message.channel = channel
+        message.author = user
+        message.content = ctx.prefix + command
+        context = await self.bot.get_context(message, cls=type(ctx))
+        await self.bot.invoke(context)
+
     @commands.is_owner()
     @commands.bot_has_permissions(send_messages=True)
     @commands.group(name="cog")
@@ -133,6 +206,8 @@ class Meta(commands.Cog):
         Cog related commands and utilities
         """
 
+        import copy
+
         pass
 
     @commands.is_owner()
@@ -143,11 +218,11 @@ class Meta(commands.Cog):
         Lists all cogs currently running on the bot
         """
 
-        await self.bot.paginate(
+        await paginate(
             ctx,
-            "Cog List",
-            "`{0}`",
-            list(self.bot.cogs.keys()),
+            embed_title="Cog List",
+            line="`{0}`",
+            sequence=list(self.bot.cogs.keys()),
             max_page_size=1024,
             sequence_type_name="cogs",
             author_name=str(self.bot.user),
