@@ -122,10 +122,3 @@ class Database:
                     await db.commit()
 
                 return result
-
-
-if __name__ == "__main__":
-    table = Table("test_table")
-    table.add_column(name="id", datatype=DataType.integer, not_null=True, primary_key=True)
-    table.add_column(name="test", datatype=DataType.real, default=0.0)
-    print(table.sql)
