@@ -23,13 +23,6 @@ def get_discord_color(color: Union[discord.Color, tuple, str]) -> discord.Color:
     A discord.Color object
     """
 
-    print(f"Color: \"{color}\" (type: {type(color)})")
-    print(f"Color is discord.Color: {color is discord.Color}")
-    print(f"Color is discord.Colour: {color is discord.Colour}")
-    print(f"Color isinstance of discord.Color: {isinstance(color, discord.Color)}")
-    print(f"Color isinstance of discord.Colour: {isinstance(color, discord.Colour)}")
-    print(f"Color isinstance of discord.Color or discord.Colour: {isinstance(color, (discord.Color, discord.Colour))}")
-
     if type(color) is tuple:
         # assuming it's RGB
         return discord.Color.from_rgb(color[0], color[1], color[2])
